@@ -21,12 +21,13 @@ from os import path
 from typing import Any, cast
 
 from pytensor import function
-from pytensor.graph.basic import ancestors, walk
+from pytensor.graph.basic import Variable
+from pytensor.graph.traversal import ancestors, walk
 from pytensor.tensor.shape import Shape
-from pytensor.tensor.variable import TensorVariable
 
 from pymc.model.core import modelcontext
-from pymc.util import VarName, get_default_varnames, get_var_name
+from pymc.pytensorf import _cheap_eval_mode
+from pymc.util import get_default_varnames, get_var_name
 
 __all__ = (
     "ModelGraph",
@@ -73,7 +74,7 @@ def create_plate_label_with_dim_length(
 
 
 def fast_eval(var):
-    return function([], var, mode="FAST_COMPILE")()
+    return function([], var, mode=_cheap_eval_mode)()
 
 
 class NodeType(str, Enum):
@@ -88,7 +89,7 @@ class NodeType(str, Enum):
 
 @dataclass
 class NodeInfo:
-    var: TensorVariable
+    var: Variable
     node_type: NodeType
 
     def __hash__(self):
@@ -108,10 +109,10 @@ class Plate:
 
 
 GraphvizNodeKwargs = dict[str, Any]
-NodeFormatter = Callable[[TensorVariable], GraphvizNodeKwargs]
+NodeFormatter = Callable[[Variable], GraphvizNodeKwargs]
 
 
-def default_potential(var: TensorVariable) -> GraphvizNodeKwargs:
+def default_potential(var: Variable) -> GraphvizNodeKwargs:
     """Return default data for potential in the graph."""
     return {
         "shape": "octagon",
@@ -120,17 +121,19 @@ def default_potential(var: TensorVariable) -> GraphvizNodeKwargs:
     }
 
 
-def random_variable_symbol(var: TensorVariable) -> str:
+def random_variable_symbol(var: Variable) -> str:
     """Get the symbol of the random variable."""
-    symbol = var.owner.op.__class__.__name__
+    op = var.owner.op
 
-    if symbol.endswith("RV"):
-        symbol = symbol[:-2]
+    if name := getattr(op, "name", None):
+        symbol = name[0].upper() + name[1:]
+    else:
+        symbol = op.__class__.__name__.removesuffix("RV")
 
     return symbol
 
 
-def default_free_rv(var: TensorVariable) -> GraphvizNodeKwargs:
+def default_free_rv(var: Variable) -> GraphvizNodeKwargs:
     """Return default data for free RV in the graph."""
     symbol = random_variable_symbol(var)
 
@@ -141,7 +144,7 @@ def default_free_rv(var: TensorVariable) -> GraphvizNodeKwargs:
     }
 
 
-def default_observed_rv(var: TensorVariable) -> GraphvizNodeKwargs:
+def default_observed_rv(var: Variable) -> GraphvizNodeKwargs:
     """Return default data for observed RV in the graph."""
     symbol = random_variable_symbol(var)
 
@@ -152,7 +155,7 @@ def default_observed_rv(var: TensorVariable) -> GraphvizNodeKwargs:
     }
 
 
-def default_deterministic(var: TensorVariable) -> GraphvizNodeKwargs:
+def default_deterministic(var: Variable) -> GraphvizNodeKwargs:
     """Return default data for the deterministic in the graph."""
     return {
         "shape": "box",
@@ -161,7 +164,7 @@ def default_deterministic(var: TensorVariable) -> GraphvizNodeKwargs:
     }
 
 
-def default_data(var: TensorVariable) -> GraphvizNodeKwargs:
+def default_data(var: Variable) -> GraphvizNodeKwargs:
     """Return default data for the data in the graph."""
     return {
         "shape": "box",
@@ -170,7 +173,7 @@ def default_data(var: TensorVariable) -> GraphvizNodeKwargs:
     }
 
 
-def get_node_type(var_name: VarName, model) -> NodeType:
+def get_node_type(var_name: str, model) -> NodeType:
     """Return the node type of the variable in the model."""
     v = model[var_name]
 
@@ -239,7 +242,7 @@ class ModelGraph:
         self._all_vars = {model[var_name] for var_name in self._all_var_names}
         self.var_list = self.model.named_vars.values()
 
-    def get_parent_names(self, var: TensorVariable) -> set[VarName]:
+    def get_parent_names(self, var: Variable) -> set[str]:
         if var.owner is None:
             return set()
 
@@ -258,12 +261,12 @@ class ModelGraph:
             return x.owner.inputs
 
         return {
-            cast(VarName, ancestor.name)  # type: ignore[union-attr]
+            cast(str, ancestor.name)  # type: ignore[union-attr]
             for ancestor in walk(nodes=var.owner.inputs, expand=_expand)
             if ancestor in named_vars
         }
 
-    def vars_to_plot(self, var_names: Iterable[VarName] | None = None) -> list[VarName]:
+    def vars_to_plot(self, var_names: Iterable[str] | None = None) -> list[str]:
         if var_names is None:
             return self._all_var_names
 
@@ -293,13 +296,11 @@ class ModelGraph:
         # ordering of self._all_var_names is important
         return [get_var_name(var) for var in selected_ancestors]
 
-    def make_compute_graph(
-        self, var_names: Iterable[VarName] | None = None
-    ) -> dict[VarName, set[VarName]]:
+    def make_compute_graph(self, var_names: Iterable[str] | None = None) -> dict[str, set[str]]:
         """Get map of var_name -> set(input var names) for the model."""
         model = self.model
         named_vars = self._all_vars
-        input_map: dict[VarName, set[VarName]] = defaultdict(set)
+        input_map: dict[str, set[str]] = defaultdict(set)
 
         var_names_to_plot = self.vars_to_plot(var_names)
         for var_name in var_names_to_plot:
@@ -316,7 +317,7 @@ class ModelGraph:
                 for ancestor in ancestors([obs_var]):
                     if ancestor not in named_vars:
                         continue
-                    obs_name = cast(VarName, ancestor.name)
+                    obs_name = cast(str, ancestor.name)
                     input_map[var_name].discard(obs_name)
                     input_map[obs_name].add(var_name)
 
@@ -324,7 +325,7 @@ class ModelGraph:
 
     def get_plates(
         self,
-        var_names: Iterable[VarName] | None = None,
+        var_names: Iterable[str] | None = None,
     ) -> list[Plate]:
         """Rough but surprisingly accurate plate detection.
 
@@ -334,7 +335,7 @@ class ModelGraph:
         Returns
         -------
         dict
-            Maps plate labels to the set of ``VarName``s inside the plate.
+            Maps plate labels to the set of strings inside the plate.
         """
         plates = defaultdict(set)
 
@@ -345,7 +346,7 @@ class ModelGraph:
             dim_name: fast_eval(value).item() for dim_name, value in self.model.dim_lengths.items()
         }
         var_shapes: dict[str, tuple[int, ...]] = {
-            var_name: tuple(fast_eval(self.model[var_name].shape))
+            var_name: tuple(map(int, fast_eval(self.model[var_name].shape)))
             for var_name in self.vars_to_plot(var_names)
         }
 
@@ -386,8 +387,8 @@ class ModelGraph:
 
     def edges(
         self,
-        var_names: Iterable[VarName] | None = None,
-    ) -> list[tuple[VarName, VarName]]:
+        var_names: Iterable[str] | None = None,
+    ) -> list[tuple[str, str]]:
         """Get edges between the variables in the model.
 
         Parameters
@@ -402,7 +403,7 @@ class ModelGraph:
 
         """
         return [
-            (VarName(child.replace(":", "&")), VarName(parent.replace(":", "&")))
+            (str(child.replace(":", "&")), str(parent.replace(":", "&")))
             for child, parents in self.make_compute_graph(var_names=var_names).items()
             for parent in parents
         ]
@@ -419,7 +420,7 @@ class ModelGraph:
 def make_graph(
     name: str,
     plates: list[Plate],
-    edges: list[tuple[VarName, VarName]],
+    edges: list[tuple[str, str]],
     formatting: str = "plain",
     save=None,
     figsize=None,
@@ -493,7 +494,7 @@ def make_graph(
 def make_networkx(
     name: str,
     plates: list[Plate],
-    edges: list[tuple[VarName, VarName]],
+    edges: list[tuple[str, str]],
     formatting: str = "plain",
     node_formatters: NodeTypeFormatterMapping | None = None,
     create_plate_label: PlateLabelFunc = create_plate_label_with_dim_length,
@@ -563,7 +564,7 @@ def make_networkx(
 def model_to_networkx(
     model=None,
     *,
-    var_names: Iterable[VarName] | None = None,
+    var_names: Iterable[str] | None = None,
     formatting: str = "plain",
     node_formatters: NodeTypeFormatterMapping | None = None,
     include_dim_lengths: bool = True,
@@ -657,7 +658,7 @@ def model_to_networkx(
 def model_to_graphviz(
     model=None,
     *,
-    var_names: Iterable[VarName] | None = None,
+    var_names: Iterable[str] | None = None,
     formatting: str = "plain",
     save: str | None = None,
     figsize: tuple[int, int] | None = None,
